Resting state and noise acquisition — BCI-Framework documentation

# Resting state and noise acquisition

class `bci_framework.default_extensions.Resting_state_and_noise_acquisition.main.` `RestingNoiseAcquisition`

  Resting state and noise acquisition

  `beep`(n=1) → None

    Play n beeps.

  `build_trials`() → None

    Define the trials and pipeline trials.

    The trials consist (in this case) in a list of cues. The pipeline trials is a set of couples (callable, duration) that define a single trial, this list of functions are executed asynchronously and repeated for each trial.

  `end_trial`(title, label, instruction) → None

    End of trial.

  `handle_response`(response: str) → None

    Key pressed.

  `prepare`(title: str, label: str, instruction: str) → None

    A small pause before acquisition.

  `start`() → None

    Start the run.

    A run consist in a consecutive pipeline trials execution.

  `stop`() → None

    Stop pipeline execution.

  `synchronizer`(value: bool) → None

    Show or hide synchronizer.

  `syncrhonous_trial`() → None

    Start a trial after subject decision.

  `trial`(title: str, label: str, instruction: str) → None

    Full trial.

  `trial_instruction`(title: str, label: str, instruction: str) → None

    Show the trial instructions to the subject.